@@ -600,6 +600,42 @@ class A3Behavior extends Behavior {
         vv.scale(l);
         addLocImmediately(vv);
     }
+    public final void turnUp(double deg) {
+        mulQuat(Util.euler2quat(-deg/180.0*Math.PI,0,0));
+    }
+    public final void turnUpNow(double deg) {
+        mulQuatImmediately(Util.euler2quat(-deg/180.0*Math.PI,0,0));
+    }
+    public final void turnDown(double deg) {
+        mulQuat(Util.euler2quat(deg/180.0*Math.PI,0,0));
+    }
+    public final void turnDownNow(double deg) {
+        mulQuatImmediately(Util.euler2quat(deg/180.0*Math.PI,0,0));
+    }
+    public final void turnRight(double deg) {
+        mulQuat(Util.euler2quat(0,-deg/180.0*Math.PI,0));
+    }
+    public final void turnRightNow(double deg) {
+        mulQuatImmediately(Util.euler2quat(0,-deg/180.0*Math.PI,0));
+    }
+    public final void turnLeft(double deg) {
+        mulQuat(Util.euler2quat(0,deg/180.0*Math.PI,0));
+    }
+    public final void turnLeftNow(double deg) {
+        mulQuatImmediately(Util.euler2quat(0,deg/180.0*Math.PI,0));
+    }
+    public final void rollRight(double deg) {
+        mulQuat(Util.euler2quat(0,0,deg/180.0*Math.PI));
+    }
+    public final void rollRightNow(double deg) {
+        mulQuatImmediately(Util.euler2quat(0,0,deg/180.0*Math.PI));
+    }
+    public final void rollLeft(double deg) {
+        mulQuat(Util.euler2quat(0,0,-deg/180.0*Math.PI));
+    }
+    public final void rollLeftNow(double deg) {
+        mulQuatImmediately(Util.euler2quat(0,0,-deg/180.0*Math.PI));
+    }
 
     Vector3d getUnitVecX() {
         return Util.trans(nowQ,new Vector3d(1.0,0.0,0.0));
