@@ -360,6 +360,139 @@ public interface A3CanvasInterface {
      */
     public void moveCameraToImmediately(A3Object a, double l,int scene);
 
+
+
+
+
+
+
+    /**
+     * 指定した角度(degree)だけカメラを上の方に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraUp(double deg);
+
+    /**
+     * 指定した角度(degree)だけカメラを上の方に即時に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraUpNow(double deg);
+
+    /**
+     * シーンを指定して、指定した角度(degree)だけカメラを上の方に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraUp(double deg,int scene);
+
+    /**
+     * シーンを指定して、指定した角度(degree)だけカメラを上の方に即時に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraUpNow(double deg,int scene);
+
+    /**
+     * 指定した角度(degree)だけカメラを下の方に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraDown(double deg);
+
+    /**
+     * 指定した角度(degree)だけカメラを下の方に即時に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraDownNow(double deg);
+
+    /**
+     * シーンを指定して、指定した角度(degree)だけカメラを下の方に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraDown(double deg,int scene);
+
+    /**
+     * シーンを指定して、指定した角度(degree)だけカメラを下の方に即時に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraDownNow(double deg,int scene);
+
+    /**
+     * 指定した角度(degree)だけカメラを右の方に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraRight(double deg);
+
+    /**
+     * 指定した角度(degree)だけカメラを右の方に即時に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraRightNow(double deg);
+
+    /**
+     * シーンを指定して、指定した角度(degree)だけカメラを右の方に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraRight(double deg,int scene);
+
+    /**
+     * シーンを指定して、指定した角度(degree)だけカメラを右の方に即時に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraRightNow(double deg,int scene);
+
+    /**
+     * 指定した角度(degree)だけカメラを左の方に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraLeft(double deg);
+
+    /**
+     * 指定した角度(degree)だけカメラを左の方に即時に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraLeftNow(double deg);
+
+    /**
+     * シーンを指定して、指定した角度(degree)だけカメラを左の方に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraLeft(double deg,int scene);
+
+    /**
+     * シーンを指定して、指定した角度(degree)だけカメラを左の方に即時に回転します。方向はカメラを基準とした方向です。
+     */
+    public void turnCameraLeftNow(double deg,int scene);
+
+    /**
+     * 指定した角度(degree)だけカメラを右に傾けます。正確にはカメラの前方方向に右ネジを進める時と同じ方向に回転させます。
+     */
+    public void rollCameraRight(double deg);
+
+    /**
+     * 指定した角度(degree)だけカメラを右に即時に傾けます。正確にはカメラの前方方向に右ネジを進める時と同じ方向に回転させます。
+     */
+    public void rollCameraRightNow(double deg);
+
+    /**
+     * シーンを指定して、指定した角度(degree)だけカメラを右に傾けます。正確にはカメラの前方方向に右ネジを進める時と同じ方向に回転させます。
+     */
+    public void rollCameraRight(double deg,int scene);
+
+    /**
+     * シーンを指定して、指定した角度(degree)だけカメラを右に即時に傾けます。正確にはカメラの前方方向に右ネジを進める時と同じ方向に回転させます。
+     */
+    public void rollCameraRightNow(double deg,int scene);
+
+    /**
+     * 指定した角度(degree)だけカメラを左に傾けます。正確にはカメラの前方方向に右ネジを進める時と逆方向に回転させます。
+     */
+    public void rollCameraLeft(double deg);
+
+    /**
+     * 指定した角度(degree)だけカメラを左に即時に傾けます。正確にはカメラの前方方向に右ネジを進める時と逆方向に回転させます。
+     */
+    public void rollCameraLeftNow(double deg);
+
+    /**
+     * シーンを指定して、指定した角度(degree)だけカメラを左に傾けます。正確にはカメラの前方方向に右ネジを進める時と逆方向に回転させます。
+     */
+    public void rollCameraLeft(double deg,int scene);
+
+    /**
+     * シーンを指定して、指定した角度(degree)だけカメラを左に即時に傾けます。正確にはカメラの前方方向に右ネジを進める時と逆方向に回転させます。
+     */
+    public void rollCameraLeftNow(double deg,int scene);
+
+
+
+
+
+
+
+
     /**
      * カメラの現在位置を返します。
      */
@@ -659,13 +792,13 @@ public interface A3CanvasInterface {
          * 用いる方法を検討して下さい。 */
         CHASE,
         /** FPS(First Person Shooting)で良くつかわれるようなナビゲーションです。
-         * a,dで左右，w,sで前後に動き，キーボードの方向キーで視点を変更します．
-         * 視点がどちらを向いていても移動で高さが変らないようにしています．
+         * a,dで左右、w,sで前後に動き、キーボードの方向キーで視点を変更します。
+         * 視点がどちらを向いていても移動で高さが変らないようにしています。
          */
         FPS,
-        /** FPS(First Person Shooting)で良くつかわれるようなナビゲーションですが，
+        /** FPS(First Person Shooting)で良くつかわれるようなナビゲーションですが、
          * 視点の方向によって地面をはなれる方向にも移動できます。
-         * a,dで左右，w,sで前後に動き，キーボードの方向キーで視点を変更します．
+         * a,dで左右、w,sで前後に動き、キーボードの方向キーで視点を変更します。
          */
         FPS_FLY,
         /** ユーザ定義のナビゲーションモードです。 */
@@ -695,8 +828,8 @@ public interface A3CanvasInterface {
     /**
      * A3Controllerをセットします。これをセットするとナビゲーションモードが
      * USERに自動的にセットされるので、以前設定していたモードは無効になります。
-     * また，設定されているA3Controllerを解除して無効にするためには引数に
-     * nullを指定して呼び出して下さい．
+     * また、設定されているA3Controllerを解除して無効にするためには引数に
+     * nullを指定して呼び出して下さい。
      */
     public void setA3Controller(A3Controller c);
 //  ----------座標変換とピッキングのためのラッパーメソッド---------
@@ -1202,7 +1335,7 @@ public interface A3CanvasInterface {
     /**
      * シーンを指定して、ナビゲーションの大まかなスピードを設定します。
      * A3Controllerの作成者はこのスピードを参照して
-     * ナビゲーションのスピードを計算することが望まれます．
+     * ナビゲーションのスピードを計算することが望まれます。
      */
     public void setNavigationSpeed(double s,int scene);
 
@@ -1214,8 +1347,8 @@ public interface A3CanvasInterface {
     /**
      * シーンを指定して、A3Controllerをセットします。これをセットするとナビゲーションモードが
      * USERに自動的にセットされるので、以前設定していたモードは無効になります。
-     * また，設定されているA3Controllerを解除して無効にするためには引数に
-     * nullを指定して呼び出して下さい．
+     * また、設定されているA3Controllerを解除して無効にするためには引数に
+     * nullを指定して呼び出して下さい。
      */
     public void setA3Controller(A3Controller c,int scene);
 
@@ -1388,15 +1521,15 @@ public interface A3CanvasInterface {
     /**
      * カメラの補間のスピードを調節するための係数を指定します。1.0から0.0の
      * 間の数値を指定して下さい。小さいほど補間が速くなります。0.0に設定したら
-     * まったく補完されないようになります．
+     * まったく補完されないようになります。
      * デフォルトは0.1です。
      */
     public void setCameraInterpolateRatio(double ir);
 
     /**
-     * Zバッファの処理方法を変更します．具体的には
+     * Zバッファの処理方法を変更します。具体的には
      * View.setDepthBufferFreezeTransparent(boolean)を
-     * そのまま呼び出します．
+     * そのまま呼び出します。
      */
     public void setDepthBufferFreezeTransparent(boolean b);
 
@@ -1404,14 +1537,14 @@ public interface A3CanvasInterface {
     //CameraInterface
     //################################################################################
     /**
-     * ViewPlatformを内包するTransformGroupを返すメソッドですが，
-     * ライブラリ内部で仕様する物なので利用しないで下さい．
+     * ViewPlatformを内包するTransformGroupを返すメソッドですが、
+     * ライブラリ内部で仕様する物なので利用しないで下さい。
      */
     public TransformGroup getTransformGroupForViewPlatform();
 
     /**
-     * 内部で使用しているjavax.media.j3d.Canvas3Dを返すメソッドですが，
-     * ライブラリ内部で仕様する物なので利用しないで下さい．
+     * 内部で使用しているjavax.media.j3d.Canvas3Dを返すメソッドですが、
+     * ライブラリ内部で仕様する物なので利用しないで下さい。
      */
     public Canvas3D getCanvas3D();
 
@@ -1419,31 +1552,31 @@ public interface A3CanvasInterface {
     //SubCanvas
     //################################################################################
     /**
-     * ViewPlatformを含むBranchGroupを返すメソッドですが，
-     * ライブラリ内部で仕様する物なので利用しないで下さい．
+     * ViewPlatformを含むBranchGroupを返すメソッドですが、
+     * ライブラリ内部で仕様する物なので利用しないで下さい。
      */
     public BranchGroup getBranchGroupForViewPlatform();
 
     /**
-     * PickingBehaviorをセットするためのメソッドですが，
-     * ライブラリ内部で仕様する物なので利用しないで下さい．
+     * PickingBehaviorをセットするためのメソッドですが、
+     * ライブラリ内部で仕様する物なので利用しないで下さい。
      */
     public void setPickingBehavior(PickingBehavior pb);
 
     /**
-     * A3VirtualUniverseをセットするメソッドですが，
-     * ライブラリ内部で仕様する物なので利用しないで下さい．
+     * A3VirtualUniverseをセットするメソッドですが、
+     * ライブラリ内部で仕様する物なので利用しないで下さい。
      */
     public void setVirtualUniverse(A3VirtualUniverse vu);
 
     /**
-     * セットされているA3VirtualUniverseを返すメソッドですが，
-     * ライブラリ内部で仕様する物なので利用しないで下さい．
+     * セットされているA3VirtualUniverseを返すメソッドですが、
+     * ライブラリ内部で仕様する物なので利用しないで下さい。
      */
     public A3VirtualUniverse getVirtualUniverse();
 
     //################################################################################
-    //Now系メソッド．Immediatelyを呼ぶだけでOK．
+    //Now系メソッド。Immediatelyを呼ぶだけでOK。
     //################################################################################
 
     /**
