@@ -1074,6 +1074,98 @@ public abstract class A3Object {
         behavior.moveToImmediately(a.getLoc(),l);
     }
 
+    /**
+     * 指定した角度(degree)だけ上の方向に回転します。方向はキャラクタ
+     * を基準とした方向です。
+     */
+    public final void turnUp(double deg) {
+        behavior.turnUp(deg);
+    }
+
+    /**
+     * 指定した角度(degree)だけ上の方向に即時に回転します。方向はキャラクタ
+     * を基準とした方向です。
+     */
+    public final void turnUpNow(double deg) {
+        behavior.turnUpNow(deg);
+    }
+
+    /**
+     * 指定した角度(degree)だけ下の方向に回転します。方向はキャラクタ
+     * を基準とした方向です。
+     */
+    public final void turnDown(double deg) {
+        behavior.turnDown(deg);
+    }
+
+    /**
+     * 指定した角度(degree)だけ下の方向に即時に回転します。方向はキャラクタ
+     * を基準とした方向です。
+     */
+    public final void turnDownNow(double deg) {
+        behavior.turnDownNow(deg);
+    }
+
+    /**
+     * 指定した角度(degree)だけ右の方向に回転します。方向はキャラクタ
+     * を基準とした方向です。
+     */
+    public final void turnRight(double deg) {
+        behavior.turnRight(deg);
+    }
+
+    /**
+     * 指定した角度(degree)だけ右の方向に即時に回転します。方向はキャラクタ
+     * を基準とした方向です。
+     */
+    public final void turnRightNow(double deg) {
+        behavior.turnRightNow(deg);
+    }
+
+    /**
+     * 指定した角度(degree)だけ左の方向に回転します。方向はキャラクタ
+     * を基準とした方向です。
+     */
+    public final void turnLeft(double deg) {
+        behavior.turnLeft(deg);
+    }
+
+    /**
+     * 指定した角度(degree)だけ左の方向に即時に回転します。方向はキャラクタ
+     * を基準とした方向です。
+     */
+    public final void turnLeftNow(double deg) {
+        behavior.turnLeftNow(deg);
+    }
+
+    /**
+     * 指定した角度(degree)だけ右に傾けます。正確にはオブジェクトの前方方向に右ネジを進める時と同じ方向に回転させます。
+     */
+    public void rollRight(double deg) {
+        behavior.rollRight(deg);
+    }
+
+    /**
+     * 指定した角度(degree)だけ右に即時に傾けます。正確にはオブジェクトの前方方向に右ネジを進める時と同じ方向に回転させます。
+     */
+    public void rollRightNow(double deg) {
+        behavior.rollRightNow(deg);
+    }
+
+    /**
+     * 指定した角度(degree)だけ左に傾けます。正確にはオブジェクトの前方方向に右ネジを進める時と逆方向に回転させます。
+     */
+    public void rollLeft(double deg) {
+        behavior.rollLeft(deg);
+    }
+
+    /**
+     * 指定した角度(degree)だけ左に即時に傾けます。正確にはオブジェクトの前方方向に右ネジを進める時と逆方向に回転させます。
+     */
+    public void rollLeftNow(double deg) {
+        behavior.rollLeftNow(deg);
+    }
+
     /**
      * このオブジェクトのローカルな座標系のX軸がグローバルな
      * 仮想空間の座標系ではどちらの方向になるのかを返します。
