@@ -54,6 +54,7 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
     }
 
     static GraphicsConfiguration createGraphicsConfiguration() {
+        jp.sourceforge.acerola3d.A23.initA23();//2014,11/10追加(FrustumCulling=falseのためだけに)
         GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
         GraphicsDevice gd = ge.getDefaultScreenDevice();
         GraphicsConfiguration gcs[] = gd.getConfigurations();
@@ -2431,4 +2432,169 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         setCameraLookAtPointImmediately(x,y,z,up,scene);
     }
 
+
+
+
+
+
+    //################################################################################
+    //turn系メソッド．
+    //################################################################################
+    @Override
+    public void turnCameraUp(double deg) {
+        subCamBehavior.turnCameraUp(deg);
+    }
+    @Override
+    public void turnCameraUpNow(double deg) {
+        subCamBehavior.turnCameraUpNow(deg);
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraUp(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraUpNow(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    @Override
+    public void turnCameraDown(double deg) {
+        subCamBehavior.turnCameraDown(deg);
+    }
+    @Override
+    public void turnCameraDownNow(double deg) {
+        subCamBehavior.turnCameraDownNow(deg);
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraDown(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraDownNow(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    @Override
+    public void turnCameraRight(double deg) {
+        subCamBehavior.turnCameraRight(deg);
+    }
+    @Override
+    public void turnCameraRightNow(double deg) {
+        subCamBehavior.turnCameraRightNow(deg);
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraRight(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraRightNow(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    @Override
+    public void turnCameraLeft(double deg) {
+        subCamBehavior.turnCameraLeft(deg);
+    }
+    @Override
+    public void turnCameraLeftNow(double deg) {
+        subCamBehavior.turnCameraLeftNow(deg);
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraLeft(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraLeftNow(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    @Override
+    public void rollCameraRight(double deg) {
+        subCamBehavior.rollCameraRight(deg);
+    }
+    @Override
+    public void rollCameraRightNow(double deg) {
+        subCamBehavior.rollCameraRightNow(deg);
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void rollCameraRight(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void rollCameraRightNow(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    @Override
+    public void rollCameraLeft(double deg) {
+        subCamBehavior.rollCameraLeft(deg);
+    }
+    @Override
+    public void rollCameraLeftNow(double deg) {
+        subCamBehavior.rollCameraLeftNow(deg);
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void rollCameraLeft(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void rollCameraLeftNow(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
 }
