@@ -2248,4 +2248,151 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
         setCameraLookAtPointImmediately(x,y,z,up,scene);
     }
 
+    //################################################################################
+    //turn系メソッド．
+    //################################################################################
+    @Override
+    public void turnCameraUp(double deg) {
+        scene.turnCameraUp(deg);
+    }
+    @Override
+    public void turnCameraUpNow(double deg) {
+        scene.turnCameraUpNow(deg);
+    }
+    @Override
+    public void turnCameraUp(double deg,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.turnCameraUp(deg);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void turnCameraUpNow(double deg,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.turnCameraUpNow(deg);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void turnCameraDown(double deg) {
+        scene.turnCameraDown(deg);
+    }
+    @Override
+    public void turnCameraDownNow(double deg) {
+        scene.turnCameraDownNow(deg);
+    }
+    @Override
+    public void turnCameraDown(double deg,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.turnCameraDown(deg);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void turnCameraDownNow(double deg,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.turnCameraDownNow(deg);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void turnCameraRight(double deg) {
+        scene.turnCameraRight(deg);
+    }
+    @Override
+    public void turnCameraRightNow(double deg) {
+        scene.turnCameraRightNow(deg);
+    }
+    @Override
+    public void turnCameraRight(double deg,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.turnCameraRight(deg);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void turnCameraRightNow(double deg,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.turnCameraRightNow(deg);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void turnCameraLeft(double deg) {
+        scene.turnCameraLeft(deg);
+    }
+    @Override
+    public void turnCameraLeftNow(double deg) {
+        scene.turnCameraLeftNow(deg);
+    }
+    @Override
+    public void turnCameraLeft(double deg,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.turnCameraLeft(deg);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void turnCameraLeftNow(double deg,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.turnCameraLeftNow(deg);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void rollCameraRight(double deg) {
+        scene.rollCameraRight(deg);
+    }
+    @Override
+    public void rollCameraRightNow(double deg) {
+        scene.rollCameraRightNow(deg);
+    }
+    @Override
+    public void rollCameraRight(double deg,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.rollCameraRight(deg);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void rollCameraRightNow(double deg,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.rollCameraRightNow(deg);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void rollCameraLeft(double deg) {
+        scene.rollCameraLeft(deg);
+    }
+    @Override
+    public void rollCameraLeftNow(double deg) {
+        scene.rollCameraLeftNow(deg);
+    }
+    @Override
+    public void rollCameraLeft(double deg,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.rollCameraLeft(deg);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void rollCameraLeftNow(double deg,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.rollCameraLeftNow(deg);
+        else
+            throw new IllegalArgumentException();
+    }
 }
