@@ -32,6 +32,7 @@ public class EduWindow extends JFrame implements A3CanvasInterface, ActionListen
      * (w,h)の大きさのEduWindowを生成します。
      */
     public EduWindow(int w,int h) {
+        jp.sourceforge.acerola3d.A23.initA23();//2014,11/10追加(FrustumCulling=falseのためだけに)
         final int ww = w;
         final int hh = h;
         try {
@@ -1731,4 +1732,108 @@ public class EduWindow extends JFrame implements A3CanvasInterface, ActionListen
         setCameraLookAtPointImmediately(x,y,z,up,scene);
     }
 
+
+
+
+
+
+    //################################################################################
+    //turn系メソッド．
+    //################################################################################
+    @Override
+    public void turnCameraUp(double deg) {
+        canvas.turnCameraUp(deg);
+    }
+    @Override
+    public void turnCameraUpNow(double deg) {
+        canvas.turnCameraUpNow(deg);
+    }
+    @Override
+    public void turnCameraUp(double deg,int scene) {
+        canvas.turnCameraUp(deg,scene);
+    }
+    @Override
+    public void turnCameraUpNow(double deg,int scene) {
+        canvas.turnCameraUpNow(deg,scene);
+    }
+    @Override
+    public void turnCameraDown(double deg) {
+        canvas.turnCameraDown(deg);
+    }
+    @Override
+    public void turnCameraDownNow(double deg) {
+        canvas.turnCameraDownNow(deg);
+    }
+    @Override
+    public void turnCameraDown(double deg,int scene) {
+        canvas.turnCameraDown(deg,scene);
+    }
+    @Override
+    public void turnCameraDownNow(double deg,int scene) {
+        canvas.turnCameraDownNow(deg,scene);
+    }
+    @Override
+    public void turnCameraRight(double deg) {
+        canvas.turnCameraRight(deg);
+    }
+    @Override
+    public void turnCameraRightNow(double deg) {
+        canvas.turnCameraRightNow(deg);
+    }
+    @Override
+    public void turnCameraRight(double deg,int scene) {
+        canvas.turnCameraRight(deg,scene);
+    }
+    @Override
+    public void turnCameraRightNow(double deg,int scene) {
+        canvas.turnCameraRightNow(deg,scene);
+    }
+    @Override
+    public void turnCameraLeft(double deg) {
+        canvas.turnCameraLeft(deg);
+    }
+    @Override
+    public void turnCameraLeftNow(double deg) {
+        canvas.turnCameraLeftNow(deg);
+    }
+    @Override
+    public void turnCameraLeft(double deg,int scene) {
+        canvas.turnCameraLeft(deg,scene);
+    }
+    @Override
+    public void turnCameraLeftNow(double deg,int scene) {
+        canvas.turnCameraLeftNow(deg,scene);
+    }
+    @Override
+    public void rollCameraRight(double deg) {
+        canvas.rollCameraRight(deg);
+    }
+    @Override
+    public void rollCameraRightNow(double deg) {
+        canvas.rollCameraRightNow(deg);
+    }
+    @Override
+    public void rollCameraRight(double deg,int scene) {
+        canvas.rollCameraRight(deg,scene);
+    }
+    @Override
+    public void rollCameraRightNow(double deg,int scene) {
+        canvas.rollCameraRightNow(deg,scene);
+    }
+    @Override
+    public void rollCameraLeft(double deg) {
+        canvas.rollCameraLeft(deg);
+    }
+    @Override
+    public void rollCameraLeftNow(double deg) {
+        canvas.rollCameraLeftNow(deg);
+    }
+    @Override
+    public void rollCameraLeft(double deg,int scene) {
+        canvas.rollCameraLeft(deg,scene);
+    }
+    @Override
+    public void rollCameraLeftNow(double deg,int scene) {
+        canvas.rollCameraLeftNow(deg,scene);
+    }
 }
