@@ -66,12 +66,17 @@ public class JA3Canvas2 extends TransCanvas3D implements A3CanvasInterface {
         this(createGraphicsConfigTemplate3D(),createGraphicsDevice(),w,h);
     }
 
+    static GraphicsConfigTemplate3D forceA23init(GraphicsConfigTemplate3D t) {
+        jp.sourceforge.acerola3d.A23.initA23();//2014,11/10追加(FrustumCulling=falseのためだけに)
+        return t;
+    }
+
     /**
      * GraphicsConfigTemplate3DとGraphicsDeviceオブジェクトを指定して
      * (w,h)の大きさのA3Canvasを作ります。
      */
     public JA3Canvas2(GraphicsConfigTemplate3D t,GraphicsDevice d,int w,int h) {
-        super(t,d,false);
+        super(forceA23init(t),d,false);
         setPreferredSize(new Dimension(w,h));
         setSize(w,h);
         this.canvasIF = this;
@@ -1670,4 +1675,108 @@ public class JA3Canvas2 extends TransCanvas3D implements A3CanvasInterface {
         setCameraLookAtPointImmediately(x,y,z,up,scene);
     }
 
+
+
+
+
+
+    //################################################################################
+    //turn系メソッド．
+    //################################################################################
+    @Override
+    public void turnCameraUp(double deg) {
+        universe.turnCameraUp(deg);
+    }
+    @Override
+    public void turnCameraUpNow(double deg) {
+        universe.turnCameraUpNow(deg);
+    }
+    @Override
+    public void turnCameraUp(double deg,int scene) {
+        universe.turnCameraUp(deg,scene);
+    }
+    @Override
+    public void turnCameraUpNow(double deg,int scene) {
+        universe.turnCameraUpNow(deg,scene);
+    }
+    @Override
+    public void turnCameraDown(double deg) {
+        universe.turnCameraDown(deg);
+    }
+    @Override
+    public void turnCameraDownNow(double deg) {
+        universe.turnCameraDownNow(deg);
+    }
+    @Override
+    public void turnCameraDown(double deg,int scene) {
+        universe.turnCameraDown(deg,scene);
+    }
+    @Override
+    public void turnCameraDownNow(double deg,int scene) {
+        universe.turnCameraDownNow(deg,scene);
+    }
+    @Override
+    public void turnCameraRight(double deg) {
+        universe.turnCameraRight(deg);
+    }
+    @Override
+    public void turnCameraRightNow(double deg) {
+        universe.turnCameraRightNow(deg);
+    }
+    @Override
+    public void turnCameraRight(double deg,int scene) {
+        universe.turnCameraRight(deg,scene);
+    }
+    @Override
+    public void turnCameraRightNow(double deg,int scene) {
+        universe.turnCameraRightNow(deg,scene);
+    }
+    @Override
+    public void turnCameraLeft(double deg) {
+        universe.turnCameraLeft(deg);
+    }
+    @Override
+    public void turnCameraLeftNow(double deg) {
+        universe.turnCameraLeftNow(deg);
+    }
+    @Override
+    public void turnCameraLeft(double deg,int scene) {
+        universe.turnCameraLeft(deg,scene);
+    }
+    @Override
+    public void turnCameraLeftNow(double deg,int scene) {
+        universe.turnCameraLeftNow(deg,scene);
+    }
+    @Override
+    public void rollCameraRight(double deg) {
+        universe.rollCameraRight(deg);
+    }
+    @Override
+    public void rollCameraRightNow(double deg) {
+        universe.rollCameraRightNow(deg);
+    }
+    @Override
+    public void rollCameraRight(double deg,int scene) {
+        universe.rollCameraRight(deg,scene);
+    }
+    @Override
+    public void rollCameraRightNow(double deg,int scene) {
+        universe.rollCameraRightNow(deg,scene);
+    }
+    @Override
+    public void rollCameraLeft(double deg) {
+        universe.rollCameraLeft(deg);
+    }
+    @Override
+    public void rollCameraLeftNow(double deg) {
+        universe.rollCameraLeftNow(deg);
+    }
+    @Override
+    public void rollCameraLeft(double deg,int scene) {
+        universe.rollCameraLeft(deg,scene);
+    }
+    @Override
+    public void rollCameraLeftNow(double deg,int scene) {
+        universe.rollCameraLeftNow(deg,scene);
+    }
 }
