@@ -89,12 +89,17 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         this(createGraphicsConfigTemplate3D(),createGraphicsDevice(),w,h);
     }
 
+    static GraphicsConfigTemplate3D forceA23init(GraphicsConfigTemplate3D t)  {
+        jp.sourceforge.acerola3d.A23.initA23();//2014,11/10追加(FrustumCulling=falseのためだけに)
+        return t;
+    }
+
     /**
      * GraphicsConfigTemplate3DとGraphicsDeviceオブジェクトを指定して
      * (w,h)の大きさのA3SubCanvasを作ります。
      */
     public JA3SubCanvas(GraphicsConfigTemplate3D t,GraphicsDevice d,int w,int h) {
-        super(t,d);
+        super(forceA23init(t),d);
         setPreferredSize(new Dimension(w,h));
         setSize(w,h);
         //本当は、以下の処理はここでやりたいところだけど、
@@ -2445,4 +2450,164 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         setCameraLookAtPointImmediately(x,y,z,up,scene);
     }
 
+
+
+
+
+
+    //################################################################################
+    //turn系メソッド．
+    //################################################################################
+    @Override
+    public void turnCameraUp(double deg) {
+        subCamBehavior.turnCameraUp(deg);
+    }
+    @Override
+    public void turnCameraUpNow(double deg) {
+        subCamBehavior.turnCameraUpNow(deg);
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraUp(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraUpNow(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    @Override
+    public void turnCameraDown(double deg) {
+        subCamBehavior.turnCameraDown(deg);
+    }
+    @Override
+    public void turnCameraDownNow(double deg) {
+        subCamBehavior.turnCameraDownNow(deg);
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraDown(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraDownNow(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    @Override
+    public void turnCameraRight(double deg) {
+        subCamBehavior.turnCameraRight(deg);
+    }
+    @Override
+    public void turnCameraRightNow(double deg) {
+        subCamBehavior.turnCameraRightNow(deg);
+    }
+    @Override
+    public void turnCameraRight(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraRightNow(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    @Override
+    public void turnCameraLeft(double deg) {
+        subCamBehavior.turnCameraLeft(deg);
+    }
+    @Override
+    public void turnCameraLeftNow(double deg) {
+        subCamBehavior.turnCameraLeftNow(deg);
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraLeft(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void turnCameraLeftNow(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    @Override
+    public void rollCameraRight(double deg) {
+        subCamBehavior.rollCameraRight(deg);
+    }
+    @Override
+    public void rollCameraRightNow(double deg) {
+        subCamBehavior.rollCameraRightNow(deg);
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void rollCameraRight(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void rollCameraRightNow(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    @Override
+    public void rollCameraLeft(double deg) {
+        subCamBehavior.rollCameraLeft(deg);
+    }
+    @Override
+    public void rollCameraLeftNow(double deg) {
+        subCamBehavior.rollCameraLeftNow(deg);
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void rollCameraLeft(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void rollCameraLeftNow(double deg,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
 }
