@@ -845,4 +845,45 @@ class Scene implements Component2DContainerInterface {
     public void setUpperDirection(A3Object.UpperDirection d) {
         upperDirection = d;
     }
+
+    //################################################################################
+    //turn系メソッド．
+    //################################################################################
+    public void turnCameraUp(double deg) {
+        mulCameraQuat(Util.euler2quat(deg/180.0*Math.PI,0,0));
+    }
+    public void turnCameraUpNow(double deg) {
+        mulCameraQuatImmediately(Util.euler2quat(deg/180.0*Math.PI,0,0));
+    }
+    public void turnCameraDown(double deg) {
+        mulCameraQuat(Util.euler2quat(-deg/180.0*Math.PI,0,0));
+    }
+    public void turnCameraDownNow(double deg) {
+        mulCameraQuatImmediately(Util.euler2quat(-deg/180.0*Math.PI,0,0));
+    }
+    public void turnCameraRight(double deg) {
+        mulCameraQuat(Util.euler2quat(0,-deg/180.0*Math.PI,0));
+    }
+    public void turnCameraRightNow(double deg) {
+        mulCameraQuatImmediately(Util.euler2quat(0,-deg/180.0*Math.PI,0));
+    }
+    public void turnCameraLeft(double deg) {
+        mulCameraQuat(Util.euler2quat(0,deg/180.0*Math.PI,0));
+    }
+    public void turnCameraLeftNow(double deg) {
+        mulCameraQuatImmediately(Util.euler2quat(0,deg/180.0*Math.PI,0));
+    }
+    public void rollCameraRight(double deg) {
+        mulCameraQuat(Util.euler2quat(0,0,-deg/180.0*Math.PI));
+    }
+    public void rollCameraRightNow(double deg) {
+        mulCameraQuatImmediately(Util.euler2quat(0,0,-deg/180.0*Math.PI));
+    }
+    public void rollCameraLeft(double deg) {
+        mulCameraQuat(Util.euler2quat(0,0,deg/180.0*Math.PI));
+    }
+    public void rollCameraLeftNow(double deg) {
+        mulCameraQuatImmediately(Util.euler2quat(0,0,deg/180.0*Math.PI));
+    }
+
 }
