@@ -566,4 +566,46 @@ class SubCameraBehavior extends Behavior {
     void setInterpolateRatio(double ir) {
         interpolateRatio = ir;
     }
+
+
+
+
+
+
+    public final void turnCameraUp(double deg) {
+        mulCameraQuat(Util.euler2quat(deg/180.0*Math.PI,0,0));
+    }
+    public final void turnCameraUpNow(double deg) {
+        mulCameraQuatImmediately(Util.euler2quat(deg/180.0*Math.PI,0,0));
+    }
+    public final void turnCameraDown(double deg) {
+        mulCameraQuat(Util.euler2quat(-deg/180.0*Math.PI,0,0));
+    }
+    public final void turnCameraDownNow(double deg) {
+        mulCameraQuatImmediately(Util.euler2quat(-deg/180.0*Math.PI,0,0));
+    }
+    public final void turnCameraRight(double deg) {
+        mulCameraQuat(Util.euler2quat(0,-deg/180.0*Math.PI,0));
+    }
+    public final void turnCameraRightNow(double deg) {
+        mulCameraQuatImmediately(Util.euler2quat(0,-deg/180.0*Math.PI,0));
+    }
+    public final void turnCameraLeft(double deg) {
+        mulCameraQuat(Util.euler2quat(0,deg/180.0*Math.PI,0));
+    }
+    public final void turnCameraLeftNow(double deg) {
+        mulCameraQuatImmediately(Util.euler2quat(0,deg/180.0*Math.PI,0));
+    }
+    public final void rollCameraRight(double deg) {
+        mulCameraQuat(Util.euler2quat(0,0,-deg/180.0*Math.PI));
+    }
+    public final void rollCameraRightNow(double deg) {
+        mulCameraQuatImmediately(Util.euler2quat(0,0,-deg/180.0*Math.PI));
+    }
+    public final void rollCameraLeft(double deg) {
+        mulCameraQuat(Util.euler2quat(0,0,deg/180.0*Math.PI));
+    }
+    public final void rollCameraLeftNow(double deg) {
+        mulCameraQuatImmediately(Util.euler2quat(0,0,deg/180.0*Math.PI));
+    }
 }
