@@ -907,4 +907,12 @@ public class Util {
         bg.addChild(scene.getSceneGroup());
         return bg;
     }
+
+    public static void sleep(long ms) {
+        try {
+            Thread.sleep(ms);
+        } catch(Exception e) {
+            e.printStackTrace();
+        }
+    }
 }
